###################################################################################################################################################
# Copyright 2015 Orchid Systems 
# -----------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an as is basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
# -------------------
# Updated: 2018/08/23 - includes system access to check to prevent script from running during D.I.C, Import, Export, etc.
###################################################################################################################################################


#################### Import Modules ###########################################
from accpac import *

import time
import datetime
import subprocess

###############################################################################

oehdr = None
arcusto = None
bOverride = 0

def onOpen():
	if rotoID != "OE0500":
		return 0 # don't do anything since the view is not OE0500 O/E sales order details.

	# Check system access to prevent running the script during Data Integrity Check, Import, Export, etc:
	if int(me.getAccess()) != 0:
		return 0.# do not run the script. System Access is not Normal.

	return Continue

def onBeforeCompose(e):
	global oehdr
	if e.views[0] is None:
		oehdr = None
	else:
		oehdr = e.views[0]
		openARCustOptionalFldView()

	return Continue

def onBeforePut(e):
	rvspyTrace("onBeforePut [" + str(e.value) + "] to [" + e.field + "]")

	if (e.field == "CATEGORY"):
		sampcat = overwriteCategory()

		if (sampcat != ""):
			e.value = sampcat

	return Continue

def onAfterPut(e):
	rvspyTrace("onAfterPut [" + str(e.value) + "] to [" + e.field + "], result=" + str(e.result))
	
	if (e.field == "ITEM"):
		sampcat = overwriteCategory()
		if (sampcat != ""):
			me.put("CATEGORY", sampcat)		


def openARCustOptionalFldView():
	global arcusto
	try:
		arcusto = openView("AR0400",1)
	except:
		arcusto = None

def overwriteCategory():
	# if the customer has the SAMPCAT optional field in their master record, then override the category with the value in that option field.

	global arcusto
	global oehdr

	sampcat = ""

	if (arcusto is None):
		openARCustOptionalFldView()

	if (arcusto is not None) and (oehdr is not None):
		# Get customer id from the OE Order Header.
		idcust = oehdr.get("CUSTOMER")
		idcust = idcust.strip()

		# build filter string for the optional field view.
		sfilter = "IDCUST = \"" + idcust + "\" AND OPTFIELD = \"SAMPCAT\""
		arcusto.recordClear()
		arcusto.browse(sfilter , 1)
		res = arcusto.fetch()
		if (res == 0):
			# optional field was found. Read the value.
			sampcat = arcusto.get("VALUE")
			sampcat = sampcat.strip()

	return sampcat